@@ -43,7 +43,7 @@ public:
     bool loadImageBufferOnly(QString fileName);
     bool loadFits(QString fileName);
     bool parseHeader();
-    bool saveAsFITS(QString fileName, FITSImage::Statistic &imageStats, uint8_t *m_ImageBuffer, FITSImage::Solution solution, QList<Record> &records, bool hasSolution);
+    bool saveAsFITS(QString fileName, FITSImage::Statistic &imageStats, uint8_t *m_ImageBuffer, FITSImage::Solution solution, const QList<Record> &records, bool hasSolution);
     bool loadOtherFormat(QString fileName);
     bool checkDebayer();
     bool debayer();
