@@ -27,8 +27,8 @@
 #include "solver.h"
 #include "verify.h"
 #include "tic.h"
-#include "solvedclient.h"
-#include "solvedfile.h"
+    //# Modified by Robert Lancaster for the StellarSolver Internal Library, removed includes
+
 #include "fit-wcs.h"
 #include "sip-utils.h"
 #include "keywords.h"
@@ -1250,6 +1250,8 @@ static void resolve_matches(kdtree_qres_t* krez, const double *field,
     int jj, thisquadno;
     MatchObj mo;
 
+    if(dimquads <= 0) //# Modified by Robert Lancaster for the StellarSolver Internal Library to resolve warning
+        return;
 #ifndef _MSC_VER //# Modified by Robert Lancaster for the StellarSolver Internal Library
         unsigned int star[dimquads];
 #else
@@ -1479,7 +1481,7 @@ static int solver_handle_hit(solver_t* sp, MatchObj* mo, sip_t* sip,
             weights[Ngood] = verify_logodds_to_weight(mo->matchodds[i]);
 
             double xx,yy;
-            Unused anbool ok;
+            VarUnused anbool ok; //# Modified by Robert Lancaster for the StellarSolver Internal Library to resolve conflict
             ok = tan_xyzarr2pixelxy(&mo->wcstan, matchxyz+3*Ngood, &xx, &yy);
             assert(ok);
             logverb("match: ref(%.1f, %.1f) -- img(%.1f, %.1f) --> dist(%.1f, %.1f)\n",
@@ -1521,7 +1523,7 @@ static int solver_handle_hit(solver_t* sp, MatchObj* mo, sip_t* sip,
 
             for (i=0; i<Ngood; i++) {
                 double xx,yy;
-                Unused anbool ok;
+                VarUnused anbool ok; //# Modified by Robert Lancaster for the StellarSolver Internal Library to resolve conflict
                 ok = sip_xyzarr2pixelxy(&sip, matchxyz+3*i, &xx, &yy);
                 assert(ok);
                 logverb("match: ref(%.1f, %.1f) -- dist(%.1f, %.1f)\n",
